export class StTimepicker {
    constructor() {
        this.step = 15;
        this.clock24 = false;
        this.label = 'Pick a time';
    }
    _getOptions() {
        const start = 0;
        const total = Math.round((60 / this.step) * 24);
        let hours = [];
        for (let i = start; i < total; i++) {
            hours.push(i * this.step);
        }
        return hours;
    }
    _format(h, m) {
        let indicator = '';
        if (!this.clock24 && h >= 12) {
            indicator = 'PM';
            h = h - 12;
        }
        else {
            if (!this.clock24 && h < 12) {
                indicator = 'AM';
            }
        }
        if (!this.clock24 && h == 0) {
            h = 12;
        }
        if (h < 10) {
            h = `0${h}`;
        }
        if (m < 10) {
            m = `0${m}`;
        }
        if (indicator)
            m = m + ` ${indicator}`;
        return `${h}:${m}`;
    }
    _renderOption(m) {
        let base = new Date(0);
        base.setMinutes(m);
        const hours = base.getUTCHours();
        const minutes = base.getUTCMinutes();
        const formatted = this._format(hours, minutes);
        if (this.selected == formatted)
            return (h("option", { value: formatted, selected: true }, formatted));
        else
            return (h("option", { value: formatted }, formatted));
    }
    render() {
        const minutes = this._getOptions();
        return (h("select", { class: this.class, name: this.name },
            h("option", { disabled: true, selected: true }, this.label),
            minutes.map((m) => this._renderOption(m))));
    }
    static get is() { return "st-timepicker"; }
    static get properties() { return {
        "class": {
            "type": String,
            "attr": "class"
        },
        "clock24": {
            "type": Boolean,
            "attr": "clock-2-4"
        },
        "el": {
            "elementRef": true
        },
        "label": {
            "type": String,
            "attr": "label"
        },
        "name": {
            "type": String,
            "attr": "name"
        },
        "selected": {
            "type": String,
            "attr": "selected"
        },
        "step": {
            "type": Number,
            "attr": "step"
        }
    }; }
}
